@@ -7,7 +7,6 @@ from bittrade_cryptodotcom_websocket.connection.bundle import WebsocketStatusBun
 from ..connection.connection_operators import filter_socket_status_only
 from ..connection.generic import WEBSOCKET_MESSAGE, WEBSOCKET_STATUS, WebsocketBundle
 from ..connection.status import Status
-from ..development import debug_operator
 from ..models import CryptodotcomResponseMessage, EnhancedWebsocket
 
 
@@ -32,14 +31,7 @@ def keep_messages_only() -> Callable[
     )
 
 
-def keep_status_only() -> Callable[[Observable[WebsocketBundle]], Observable[Status]]:
-    return compose(
-        filter_socket_status_only(),
-        message_only(),
-    )  # type: ignore
-
-
-def filter_new_socket_only() -> Callable[
+def keep_new_socket_only() -> Callable[
     [Observable[WebsocketBundle]], Observable[EnhancedWebsocket]
 ]:
     def wait(x: EnhancedWebsocket):
@@ -48,8 +40,6 @@ def filter_new_socket_only() -> Callable[
     return compose(
         operators.map(lambda x: x[0]),
         operators.distinct_until_changed(),
-        debug_operator("CONNECTION BEFORE WAIT"),
         operators.map(wait),
         operators.switch_latest(),
-        debug_operator("CONNECTION AFTER WAIT"),
     )
